summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJesusaves <cpntb1@ymail.com>2019-06-19 00:02:39 -0300
committerJesusaves <cpntb1@ymail.com>2019-06-19 00:02:39 -0300
commit64b25193fbd67efb7af8b6f9b7b2fe6be9d6c885 (patch)
tree1fe4c773e461f2ca54c2367735e930922525ebba
parentd645b4106590ae7cafdeb71a686e9ce58678176f (diff)
downloadtools-64b25193fbd67efb7af8b6f9b7b2fe6be9d6c885.tar.gz
tools-64b25193fbd67efb7af8b6f9b7b2fe6be9d6c885.tar.bz2
tools-64b25193fbd67efb7af8b6f9b7b2fe6be9d6c885.tar.xz
tools-64b25193fbd67efb7af8b6f9b7b2fe6be9d6c885.zip
beta.patch2
-rwxr-xr-xlocalserver/build.sh16
-rw-r--r--update/files/resources.xml4
2 files changed, 17 insertions, 3 deletions
diff --git a/update/files/resources.xml b/update/files/resources.xml
index 25120ec..6bfb4ea 100644
--- a/update/files/resources.xml
+++ b/update/files/resources.xml
@@ -4,6 +4,6 @@
<update type="data" file="TMW2-d21a310..a9fe624.zip" hash="d92e0443" />
<update type="data" file="TMW2-a9fe624..afbb2f5.zip" hash="eeac70ce" />
<update type="music" required="no" file="music.zip" hash="eb5f8043" description="TMW-2 music" />
- <mod type="data" group="lightcave" file="mod-lightcave.zip" hash="7462083f" />
- <mod type="data" group="mouboo" file="mod-mouboo.zip" hash="4fe20aa6" />
+ <mod type="data" group="lightcave" file="mod-lightcave.zip" hash="d6a7ccf4" />
+ <mod type="data" group="mouboo" file="mod-mouboo.zip" hash="c2330b32" />
</updates>
diff --git a/localserver/build.sh b/localserver/build.sh
index 92226ff..b1066dd 100755
--- a/localserver/build.sh
+++ b/localserver/build.sh
@@ -2,7 +2,7 @@
export DIR=`pwd`
# Apply beta.patch if it exists
# It will only exist on BETA SERVERS, though
if [ -e "./beta.patch" ]
then
@@ -10,6 +10,20 @@ if [ -e "./beta.patch" ]
cd ../../server-data
git apply ../tools/localserver/beta.patch
cd $DIR
+ mv beta.patch ~beta.patch
+ ls
+ echo "........ Done."
+fi
+
+# Apply beta.patch2 if it exists to server-code
+# It will only exist on BETA SERVERS, though
+if [ -e "./beta.patch" ]
+ then
+ echo "Apply beta.patch2 ........"
+ cd ../../server-code
+ git apply ../tools/localserver/beta.patch2
+ cd $DIR
+ mv beta.patch2 ~beta.patch2
ls
echo "........ Done."
fi
@@ -2,7 +2,7 @@
export DIR=`pwd`
-# Apply beta.patch if it exists
+# Apply beta.patch if it exists to server-data
# It will only exist on BETA SERVERS, though
if [ -e "./beta.patch" ]